# vim: set sw=4 ts=4 et nu:
#
# spec file for package lziprecover
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lziprecover
Version:        1.16
Release:        4.3
Summary:        Fix Broken lzip Files
License:        GPL-2.0+
Group:          Productivity/Archiving/Compression
Url:            http://www.nongnu.org/lzip/lunzip.html

Source:         http://download.savannah.gnu.org/releases/lzip/lziprecover/%name-%version.tar.gz
Source2:        http://download.savannah.gnu.org/releases/lzip/lziprecover/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
Requires(post):     info
Requires(preun):    info

%description
Lziprecover is a data recovery tool and decompressor for files in the
lzip compressed data format (.lz) able to repair slightly damaged
files, recover badly damaged files from two or more copies, extract
undamaged members from multi-member files, decompress files and test
integrity of files.

Lziprecover is able to recover or decompress files produced by any of
the compressors in the lzip family; lzip, plzip, minilzip/lzlib,
clzip and pdlzip. This recovery capability contributes to make the
lzip format one of the best options for long-term data archiving.

Lziprecover is able to efficiently extract a range of bytes from a
multi-member file, because it only decompresses the members
containing the desired data.

Lziprecover can print correct total file sizes and ratios even for
multi-member files.

%prep
%setup -q

%build
# not autoconf
%__install -d build
pushd build
../configure \
    --srcdir=.. \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --datarootdir="%{_datadir}" \
    --infodir="%{_infodir}" \
    --mandir="%{_mandir}" \
    CC="%__cc" \
    CFLAGS="%{optflags}"

%__make %{?_smp_mflags}
popd

%install
pushd build
make install DESTDIR="%buildroot"
popd

%post
%install_info --info-dir="%{_infodir}" "%{_infodir}/%{name}".info*

%postun
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/%{name}".info*

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README
%{_bindir}/lziprecover
%doc %{_mandir}/man1/lziprecover.1*
%doc %{_infodir}/lziprecover.info*

%changelog
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.16
  * Repairing of single-byte errors is now about 10 times faster,
  depending on file size and position of error.
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * The license has been changed to GPL version 2 or later.
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.15
  * Lziprecover can now repair multi-member files with up to one byte
  error per member, without having to split them first.
  * Lziprecover can now merge multi-member files without having to
  split them first, even if some copies have the header and the
  trailer damaged.
* Mon Jun 10 2013 jengelh@inai.de
- Update to new upstream release 1.14
  * The new option "-i, --ignore-errors", which in conjunction with
  "-D" decompresses all the recoverable data in all members of a
  file without having to split it first, has been added.
  * Option "-l, --list" now accepts more than one file.
  * Decompression time has been reduced by 12%%.
  * "--split" now uses as few digits as possible in the names of the
  files produced, depending on the number of members in the input
  file.
  * "--split" in verbose mode now shows the names of files being
  created.
- Wrap description at 70 cols; more robust make install call;
  remove redundant %%clean section; signature verification
* Tue Apr  3 2012 pascal.bleser@opensuse.org
- initial version (1.13)
